@@ -6,7 +6,7 @@
 double Bessel(double *x,double *p);
 //double ScaleBessel(double *p,int scaling); missing
 double spectralBessel(double *p );
-int checkBessel(double *param, int timespacedim, SimulationType method);
+int checkBessel(double *param, int timespacedim, int dim, SimulationType method);
 void rangeBessel(int dim, int *index, double* range);
 void infoBessel(double *p, int *maxdim, int *CEbadlybehaved);
 
@@ -16,7 +16,7 @@ double TBM2Cauchy(double *x, double *p);
 double TBM3Cauchy(double *x, double *p);
 double DCauchy(double *x, double *p);
 double DDCauchy(double *x, double *p);
-int checkCauchy(double *param, int timespacedim, SimulationType method);
+int checkCauchy(double *param, int timespacedim, int dim, SimulationType method);
 void rangeCauchy(int dim, int *index, double* range);
 void infoCauchy(double *p, int *maxdim, int *CEbadlybehaved);
 
@@ -24,7 +24,8 @@ double Cauchytbm(double *x, double *p);
 //double ScaleCauchytbm(double *p,int scaling, int dim); missing
 double TBM3Cauchytbm(double *x, double *p);
 double DCauchytbm(double *x, double *p);
-int checkCauchytbm(double *param, int timespacedim, SimulationType method);
+int checkCauchytbm(double *param, int timespacedim, int dim, 
+		   SimulationType method);
 void rangeCauchytbm(int dim, int *index, double* range);
 void infoCauchytbm(double *p, int *maxdim, int *CEbadlybehaved);
 
@@ -41,7 +42,7 @@ double Dconstant(double *x, double *p);
 void rangeconstant(int dim, int *index, double* range);
 void infoconstant(double *p, int *maxdim, int *CEbadlybehaved);
 
-int checkcone(double *param, int timespacedim, SimulationType method);
+int checkcone(double *param, int timespacedim, int dim, SimulationType method);
 void rangecone(int dim, int *index, double* range);
 void infocone(double *p, int *maxdim, int *CEbadlybehaved);
 
@@ -52,6 +53,12 @@ double Dcubic(double *x, double *p);
 void rangecubic(int dim, int *index, double* range);
 void infocubic(double *p, int *maxdim, int *CEbadlybehaved);
 
+double dagum(double *x, double *p);
+double Scaledagum(double *p,int scaling);
+double Ddagum(double *x, double *p);
+void rangedagum(int reduceddim, int *index, double* range);
+void infodagum(double *p, int *maxdim, int *CEbadlybehaved);
+
 double dampedcosine(double *x, double*p);
 double Scaledampedcosine(double *p,int scaling);
 double TBM3dampedcosine(double *x, double *p);
@@ -71,7 +78,8 @@ int hyperexponential(double radius, double *center, double *rx,
 		     double** hx, double** hy, double** hr);
 void rangeexponential(int dim, int *index, double* range);
 void infoexponential(double *p, int *maxdim, int *CEbadlybehaved);
-int checkexponential(double *param, int timespacedim, SimulationType method);
+int checkexponential(double *param, int timespacedim, int dim, 
+		     SimulationType method);
 
 double fractalBrownian(double*x, double *p);
 double DfractalBrownian(double *x, double*p);
@@ -100,7 +108,7 @@ double ScalegeneralisedCauchy(double *p,int scaling);
 double TBM3generalisedCauchy(double *x, double *p);
 double DgeneralisedCauchy(double *x, double *p);
 double DDgeneralisedCauchy(double *x, double *p);
-int checkgeneralisedCauchy(double *param, int timespacedim, 
+int checkgeneralisedCauchy(double *param, int timespacedim, int dim, 
 			   SimulationType method);
 void rangegeneralisedCauchy(int dim, int *index, double* range);
 void infogeneralisedCauchy(double *p, int *maxdim, int *CEbadlybehaved);
@@ -120,7 +128,8 @@ void infoGneiting(double *p, int *maxdim, int *CEbadlybehaved);
 
 double hyperbolic(double *x, double*p);
 // Scalehyperbolic(double *p,int scaling); missing
-int checkhyperbolic(double *param, int timespacedim, SimulationType method);
+int checkhyperbolic(double *param, int timespacedim, int dim, 
+		    SimulationType method);
 double TBM3hyperbolic(double *x, double*p);
 double Dhyperbolic(double *x, double*p);
 void rangehyperbolic(int dim, int *index, double* range);
@@ -130,7 +139,8 @@ double IacoCesare(double *x, double *p);
 //double ScaleIacoCesare(double *p, int scaling);
 void rangeIacoCesare(int dim, int *index, double* range);
 void infoIacoCesare(double *p, int *maxdim, int *CEbadlybehaved);
-int checkIacoCesare(double *param, int timespacedim, SimulationType method);
+int checkIacoCesare(double *param, int timespacedim, int dim, 
+		    SimulationType method);
 
 double lgd1(double *x, double*p);
 double Scalelgd1(double *p,int scaling);
@@ -143,7 +153,8 @@ double spacetime1(double *x,double *p);
 double TBM2spacetime1(double *x, double *p);
 //double TBM3spacetime1(double *x, double *p);
 double Dspacetime1(double *x, double *p);
-int checkspacetime1(double *param, int timespacedim, SimulationType method);
+int checkspacetime1(double *param, int timespacedim, int dim, 
+		    SimulationType method);
 void rangespacetime1(int dim, int *index, double* range);
 void infospacetime1(double *p, int *maxdim, int *CEbadlybehaved);
 
@@ -151,7 +162,8 @@ void infospacetime1(double *p, int *maxdim, int *CEbadlybehaved);
 double spacetime2(double *x,double *p);
 //double TBM3spacetime2(double *x, double *p);
 double Dspacetime2(double *x, double *p);
-int checkspacetime2(double *param, int timespacedim, SimulationType method);
+int checkspacetime2(double *param, int timespacedim, int dim, 
+		    SimulationType method);
 void rangespacetime2(int dim, int *index, double* range);
 void infospacetime2(double *p, int *maxdim, int *CEbadlybehaved);
 
@@ -159,7 +171,8 @@ double nugget(double *x, double *p);
 double Scalenugget(double *p, int scaling);
 void rangenugget(int dim, int *index, double* range);
 void infonugget(double *p, int *maxdim, int *CEbadlybehaved);
-int checknugget(double *param, int timespacedim, SimulationType method);
+int checknugget(double *param, int timespacedim, int dim, 
+		SimulationType method);
 
 double penta(double *x, double *p);
 double Scalepenta(double *p,int scaling);
@@ -173,7 +186,8 @@ double Scalepower(double *p,int scaling);
 double TBM2power(double *x, double *p);
 double TBM3power(double *x, double *p);
 double Dpower(double *x, double *p);
-int checkpower(double *param, int timespacedim, SimulationType method);
+int checkpower(double *param, int timespacedim, int dim, 
+	       SimulationType method);
 void rangepower(int dim, int *index, double* range);
 void infopower(double *p, int *maxdim, int *CEbadlybehaved);
 
@@ -198,7 +212,8 @@ double Scalestable(double *p,int scaling);
 double TBM3stable(double *x, double *p);
 double Dstable(double *x, double *p);
 double DDstable(double *x, double *p);
-int checkstable(double *param, int timespacedim, SimulationType method);
+int checkstable(double *param, int timespacedim, int dim, 
+		SimulationType method);
 void rangestable(int dim, int *index, double* range);
 void infostable(double *p, int *maxdim, int *CEbadlybehaved);
 
@@ -210,11 +225,13 @@ double SteinST1(double *x, double *p);
 int kappasSteinST1(int dim);
 void rangeSteinST1(int dim, int *index, double* range);
 void infoSteinST1(double *p, int *maxdim, int *CEbadlybehaved);
-int checkSteinST1(double *param, int timespacedim, SimulationType method);
+int checkSteinST1(double *param, int timespacedim, int dim, 
+		  SimulationType method);
 
 void infoundefined(double *p, int *maxdim, int *CEbadlybehaved);
-int checkundefined(double *param, int timespacedim, SimulationType method);
-int checkOK(double *param, int timespacedim, SimulationType method);
+int checkundefined(double *param, int timespacedim, int dim, 
+		   SimulationType method);
+int checkOK(double *param, int timespacedim, int dim, SimulationType method);
 
 // TODO: TBM3wave
 double wave(double *x, double *p);
@@ -230,7 +247,8 @@ double TBM2WhittleMatern(double *x, double *p);
 double TBM3WhittleMatern(double *x, double *p);
 double DWhittleMatern(double *x, double *p);
 double DDWhittleMatern(double *x, double *p);
-int checkWhittleMatern(double *param, int timespacedim, SimulationType method);
+int checkWhittleMatern(double *param, int timespacedim, int dim, 
+		       SimulationType method);
 void rangeWhittleMatern(int dim, int *index, double* range);
 void infoWhittleMatern(double *p, int *maxdim, int *CEbadlybehaved);
 
